%define anolis_release 1
# first two digits of version
%global release_version %%(echo %{version} | awk -F. '{print $1"."$2}')

%ifarch %{valgrind_arches}
%global has_valgrind 1
%endif

%global use_tss 0

Name:           libsecret
Version:        0.20.5
Release:        %{anolis_release}%{?dist}
Summary:        Library for storing and retrieving passwords and other secrets

License:        LGPLv2+
URL:            https://wiki.gnome.org/Projects/Libsecret
Source0:        https://download.gnome.org/sources/libsecret/%{release_version}/libsecret-%{version}.tar.xz

BuildRequires:  meson >= 0.50
BuildRequires:  pkgconfig(gi-docgen) >= 2021.7
BuildRequires:  pkgconfig(gio-2.0) >= 2.44
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.44
BuildRequires:  pkgconfig(glib-2.0) >= 2.44
BuildRequires:  pkgconfig(libgcrypt) >= 1.2.2
%if 0%{?use_tss}
BuildRequires:  pkgconfig(tss2-esys) >= 3.0.03
BuildRequires:  pkgconfig(tss2-mu) >= 3.0.03
BuildRequires:  pkgconfig(tss2-rc) >= 3.0.03
BuildRequires:  pkgconfig(tss2-tctildr) >= 3.0.03
%endif
BuildRequires:  gobject-introspection-devel
BuildRequires:  vala
BuildRequires:  gettext
BuildRequires:  xsltproc
BuildRequires:  docbook-style-xsl
%if 0%{?has_valgrind}
BuildRequires:  valgrind-devel
%endif
# For tests
%ifarch x86_64
BuildRequires:  python3-dbus
BuildRequires:  dbus-x11
BuildRequires:  python3-gobject
BuildRequires:  xorg-x11-server-Xvfb
%endif

Provides:       bundled(egglib)

%description
libsecret is a library for storing and retrieving passwords and other secrets.
It communicates with the "Secret Service" using DBus. gnome-keyring and
KSecretService are both implementations of a Secret Service.


%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%setup -q

# Use system valgrind headers instead
%if 0%{?has_valgrind}
rm -rf build/valgrind/
%endif


%build
%meson \
%if 0%{?use_tss}
  -Dtpm2=true \
%else
  -Dtpm2=false \
%endif
%{nil}

%meson_build

%install
%meson_install

%find_lang libsecret

%check
%ifarch x86_64
%{_bindir}/xvfb-run -a %{__meson} test \
    -C %{_vpath_builddir} \
    --num-processes %{_smp_build_ncpus} \
    --print-errorlogs
%endif

%files -f libsecret.lang
%license COPYING
%doc README.md NEWS
%{_bindir}/secret-tool
%{_libdir}/libsecret-1.so.0*
%dir %{_libdir}/girepository-1.0
%{_libdir}/girepository-1.0/Secret-1.typelib
%{_mandir}/man1/secret-tool.1*

%files devel
%{_includedir}/libsecret-1/
%{_libdir}/libsecret-1.so
%{_libdir}/pkgconfig/libsecret-1.pc
%{_libdir}/pkgconfig/libsecret-unstable.pc
%dir %{_datadir}/gir-1.0
%{_datadir}/gir-1.0/Secret-1.gir
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/libsecret-1.deps
%{_datadir}/vala/vapi/libsecret-1.vapi
%doc %{_datadir}/doc/libsecret-1

%changelog
* Fri Jan 20 2023 Funda Wang <fundawang@yeah.net> - 0.20.5-1
- New version 0.20.5

* Wed Mar  9 2022 Liwei Ge <liwei.glw@linux.alibaba.com> - 0.20.4-1
- Init version from upstream v0.20.4
